@@ -1,3 +1,5 @@
+# Copyright (C) 2003-2005, G. Allen Morris III, all rights reserved
+
 use strict;
 
 package Data::Tabular::Row::Extra;
@@ -15,11 +17,6 @@ sub new
     $self;
 }
 
-sub id
-{
-    1;
-}
-
 sub html_attribute_string
 {
     my $self = shift;
