@@ -1,3 +1,5 @@
+# Copyright (C) 2003-2005, G. Allen Morris III, all rights reserved
+
 use strict;
 package Data::Tabular::Row::Header;
 
@@ -58,6 +60,11 @@ sub cell_html_attributes
     };
 }
 
+sub type
+{
+    'FIXME';
+}
+
 1;
 __END__
 
